summaryrefslogtreecommitdiff
path: root/compiler/GHC/StgToByteCode.hs
diff options
context:
space:
mode:
Diffstat (limited to 'compiler/GHC/StgToByteCode.hs')
-rw-r--r--compiler/GHC/StgToByteCode.hs8
1 files changed, 3 insertions, 5 deletions
diff --git a/compiler/GHC/StgToByteCode.hs b/compiler/GHC/StgToByteCode.hs
index 1ba0687a9b..e056dadc2b 100644
--- a/compiler/GHC/StgToByteCode.hs
+++ b/compiler/GHC/StgToByteCode.hs
@@ -1716,11 +1716,9 @@ pushLiteral padded lit =
LitNumWord32 -> code Word32Rep
LitNumInt64 -> code Int64Rep
LitNumWord64 -> code Word64Rep
- -- No LitInteger's or LitNatural's should be left by the time this is
- -- called. CorePrep should have converted them all to a real core
- -- representation.
- LitNumInteger -> panic "pushAtom: LitInteger"
- LitNumNatural -> panic "pushAtom: LitNatural"
+ -- No LitNumBigNat should be left by the time this is called. CorePrep
+ -- should have converted them all to a real core representation.
+ LitNumBigNat -> panic "pushAtom: LitNumBigNat"
-- | Push an atom for constructor (i.e., PACK instruction) onto the stack.
-- This is slightly different to @pushAtom@ due to the fact that we allow